==> haskell-fold-debounce-0.2.0.11-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fold-debounce
version:              0.2.0.11
visibility:           public
id:                   fold-debounce-0.2.0.11-7mjPW9rDfZa3FeWN04aRJo
key:                  fold-debounce-0.2.0.11-7mjPW9rDfZa3FeWN04aRJo
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  ba560046dd812996ce043cf46e61fc17
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fold-debounce-0.2.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fold-debounce-0.2.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.11-7mjPW9rDfZa3FeWN04aRJo
depends:
    base-4.16.4.0 data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    stm-2.5.0.2 stm-delay-0.1.1.1-IWdTscKVXa1LhZvGatzVk8 time-1.11.1.1

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fold-debounce-0.2.0.11-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fold-debounce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fold-debounce
version:              0.2.0.11
visibility:           public
id:                   fold-debounce-0.2.0.11-Iu35ykkGIFm87dvLRDNEeY
key:                  fold-debounce-0.2.0.11-Iu35ykkGIFm87dvLRDNEeY
license:              BSD-3-Clause
maintainer:           Toshio Ito <debug.ito@gmail.com>
author:               Toshio Ito <debug.ito@gmail.com>
homepage:             https://github.com/debug-ito/fold-debounce
synopsis:             Fold multiple events that happen in a given period of time.
description:
    Fold multiple events that happen in a given period of time. See "Control.FoldDebounce".

category:             Control
abi:                  ba983d4a32faba2868b2466342661c6c
exposed:              True
exposed-modules:      Control.FoldDebounce
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fold-debounce-0.2.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fold-debounce-0.2.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fold-debounce
hs-libraries:         HSfold-debounce-0.2.0.11-Iu35ykkGIFm87dvLRDNEeY
depends:
    base-4.16.4.0 data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp
    stm-2.5.0.2 stm-delay-0.1.1.1-IWdTscKVXa1LhZvGatzVk8 time-1.11.1.1

haddock-interfaces:
    /usr/share/doc/haskell-fold-debounce/html/fold-debounce.haddock

haddock-html:         /usr/share/doc/haskell-fold-debounce/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
